@@ -14,7 +14,7 @@ class TestCliDeployState(PatchSSHTestCase):
             "-y",
             ",".join(hosts),
             path.join("tests", "test_cli", "deploy", filename),
-            f'--chdir={path.join("tests", "test_cli", "deploy")}',
+            f"--chdir={path.join('tests', 'test_cli', 'deploy')}",
         )
 
     def _assert_op_data(self, correct_op_name_and_host_names):
@@ -43,26 +43,28 @@ class TestCliDeployState(PatchSSHTestCase):
                     assert executed is False
 
     def test_deploy(self):
-        task_file_path = path.join("tasks", "a_task.py")
+        a_task_file_path = path.join("tasks", "a_task.py")
+        b_task_file_path = path.join("tasks", "b_task.py")
         nested_task_path = path.join("tasks", "another_task.py")
         correct_op_name_and_host_names = [
             ("First main operation", True),  # true for all hosts
             ("Second main operation", ("somehost",)),
-            ("{0} | First task operation".format(task_file_path), ("anotherhost",)),
-            ("{0} | Task order loop 1".format(task_file_path), ("anotherhost",)),
-            ("{0} | 2nd Task order loop 1".format(task_file_path), ("anotherhost",)),
-            ("{0} | Task order loop 2".format(task_file_path), ("anotherhost",)),
-            ("{0} | 2nd Task order loop 2".format(task_file_path), ("anotherhost",)),
+            ("{0} | First task operation".format(a_task_file_path), ("anotherhost",)),
+            ("{0} | Task order loop 1".format(a_task_file_path), ("anotherhost",)),
+            ("{0} | 2nd Task order loop 1".format(a_task_file_path), ("anotherhost",)),
+            ("{0} | Task order loop 2".format(a_task_file_path), ("anotherhost",)),
+            ("{0} | 2nd Task order loop 2".format(a_task_file_path), ("anotherhost",)),
             (
-                "{0} | {1} | Second task operation".format(task_file_path, nested_task_path),
+                "{0} | {1} | Second task operation".format(a_task_file_path, nested_task_path),
                 ("anotherhost",),
             ),
-            ("{0} | First task operation".format(task_file_path), True),
-            ("{0} | Task order loop 1".format(task_file_path), True),
-            ("{0} | 2nd Task order loop 1".format(task_file_path), True),
-            ("{0} | Task order loop 2".format(task_file_path), True),
-            ("{0} | 2nd Task order loop 2".format(task_file_path), True),
-            ("{0} | {1} | Second task operation".format(task_file_path, nested_task_path), True),
+            ("{0} | First task operation".format(a_task_file_path), True),
+            ("{0} | Task order loop 1".format(a_task_file_path), True),
+            ("{0} | 2nd Task order loop 1".format(a_task_file_path), True),
+            ("{0} | Task order loop 2".format(a_task_file_path), True),
+            ("{0} | 2nd Task order loop 2".format(a_task_file_path), True),
+            ("{0} | {1} | Second task operation".format(a_task_file_path, nested_task_path), True),
+            ("{0} | Important task operation".format(b_task_file_path), True),
             ("My deploy | First deploy operation", True),
             ("My deploy | My nested deploy | First nested deploy operation", True),
             ("My deploy | Second deploy operation", True),
