@@ -38,13 +38,13 @@ class TestCliExceptions(TestCase):
     def test_no_fact_module(self):
         self.assert_cli_exception(
             ["my-server.net", "fact", "not_a_module.SomeFact"],
-            "No such module: pyinfra.facts.not_a_module",
+            "No such module: not_a_module",
         )
 
     def test_no_fact_cls(self):
         self.assert_cli_exception(
             ["my-server.net", "fact", "server.NotAFact"],
-            "No such attribute in module pyinfra.facts.server: NotAFact",
+            "No such attribute in module server: NotAFact",
         )
 
 
@@ -54,7 +54,7 @@ class TestCliDeployExceptions(TestCase):
             "-y",
             ",".join(hosts),
             path.join("tests", "test_cli", "deploy_fails", filename),
-            f'--chdir={path.join("tests", "test_cli", "deploy_fails")}',
+            f"--chdir={path.join('tests', 'test_cli', 'deploy_fails')}",
         )
 
     def test_invalid_argument_type(self):
