@@ -10,7 +10,7 @@ def run_cli(*arguments):
     cwd = getcwd()
     pyinfra.is_cli = True
     runner = CliRunner()
-    result = runner.invoke(cli, arguments)
+    result = runner.invoke(cli, arguments, standalone_mode=False)
     pyinfra.is_cli = False
     chdir(cwd)
     return result
