@@ -3,7 +3,7 @@ from unittest import TestCase
 from unittest.mock import mock_open, patch
 
 from pyinfra.api.exceptions import InventoryError
-from pyinfra.connectors.vagrant import get_vagrant_options, make_names_data
+from pyinfra.connectors.vagrant import VagrantInventoryConnector, get_vagrant_options
 
 FAKE_VAGRANT_OPTIONS = {
     "groups": {
@@ -69,13 +69,13 @@ class TestVagrantConnector(TestCase):
     )
     @patch("pyinfra.connectors.vagrant.path.exists", lambda path: True)
     def test_make_names_data_with_options(self):
-        data = make_names_data()
+        data = list(VagrantInventoryConnector.make_names_data())
 
         assert data == [
             (
                 "@vagrant/ubuntu16",
                 {
-                    "ssh_port": "2222",
+                    "ssh_port": 2222,
                     "ssh_user": "vagrant",
                     "ssh_hostname": "127.0.0.1",
                     "ssh_key": "path/to/key",
@@ -85,7 +85,7 @@ class TestVagrantConnector(TestCase):
             (
                 "@vagrant/centos7",
                 {
-                    "ssh_port": "2200",
+                    "ssh_port": 2200,
                     "ssh_user": "vagrant",
                     "ssh_hostname": "127.0.0.1",
                     "ssh_key": "path/to/key",
@@ -103,13 +103,13 @@ class TestVagrantConnector(TestCase):
         ]
 
     def test_make_names_data_with_limit(self):
-        data = make_names_data(limit=("ubuntu16",))
+        data = list(VagrantInventoryConnector.make_names_data(name=("ubuntu16",)))
 
         assert data == [
             (
                 "@vagrant/ubuntu16",
                 {
-                    "ssh_port": "2222",
+                    "ssh_port": 2222,
                     "ssh_user": "vagrant",
                     "ssh_hostname": "127.0.0.1",
                     "ssh_key": "path/to/key",
@@ -120,4 +120,4 @@ class TestVagrantConnector(TestCase):
 
     def test_make_names_data_no_matches(self):
         with self.assertRaises(InventoryError):
-            make_names_data(limit="nope")
+            list(VagrantInventoryConnector.make_names_data(name="nope"))
