@@ -4,11 +4,14 @@ from importlib import import_module
 from os import listdir, path
 from unittest import TestCase
 
+from testgen import TestGenerator
+
 from pyinfra.api import StringCommand
 from pyinfra.api.facts import ShortFactBase
+from pyinfra.context import ctx_host, ctx_state
 from pyinfra_cli.util import json_encode
 
-from .util import JsonTest, get_command_string
+from .util import FakeState, create_host, get_command_string
 
 # show full diff on json
 TestCase.maxDiff = None
@@ -16,6 +19,9 @@ TestCase.maxDiff = None
 
 def _make_command(command_attribute, args):
     if callable(command_attribute):
+        if isinstance(args, dict):
+            return command_attribute(**args)
+
         if not isinstance(args, list):
             args = [args]
 
@@ -28,11 +34,25 @@ def make_fact_tests(folder_name):
     module = import_module("pyinfra.facts.{0}".format(module_name))
     fact = getattr(module, fact_name)()
 
-    class TestTests(TestCase, metaclass=JsonTest):
-        jsontest_files = path.join("tests", "facts", folder_name)
-        jsontest_prefix = "test_{0}_".format(fact.name)
+    class TestTests(
+        TestCase,
+        metaclass=TestGenerator,
+        tests_dir=path.join("tests", "facts", folder_name),
+        test_prefix="test_{0}_".format(fact.name),
+        test_method="_test",
+    ):
+        @classmethod
+        def setUpClass(cls):
+            # Create a global fake state that attach to context state
+            cls.state = FakeState()
 
-        def jsontest_function(self, test_name, test_data, fact=fact):
+        def _test(self, test_name, test_data, fact=fact):
+            host = create_host(self.state, facts=test_data.get("facts", {}))
+            with ctx_state.use(self.state):
+                with ctx_host.use(host):
+                    self._test_fn(test_name, test_data, fact)
+
+        def _test_fn(self, test_name, test_data, fact):
             short_fact = None
 
             if isinstance(fact, ShortFactBase):
@@ -65,7 +85,11 @@ def make_fact_tests(folder_name):
                         ),
                     )
 
-            data = fact.process(test_data["output"])
+            command_output = test_data["output"]
+            if isinstance(command_output, str):
+                command_output = command_output.splitlines()
+
+            data = fact.process(command_output)
             if short_fact:
                 data = short_fact.process_data(data)
 
