@@ -1,24 +1,23 @@
+import copy
 import json
 import os
-from datetime import datetime
-from inspect import getfullargspec
-from io import open
-from os import listdir, path
+import re
+from datetime import datetime, timezone
+from inspect import getcallargs, getfullargspec
+from os import path
 from pathlib import Path
 from unittest.mock import patch
 
 from pyinfra.api import Config, Inventory
 from pyinfra.api.util import get_kwargs_str
 
-from . import logger
-
 
 def get_command_string(command):
     value = command.get_raw_value()
     masked_value = command.get_masked_value()
     if value == masked_value:
         return value
-    return [value, masked_value]
+    return {"raw": value, "masked": masked_value}
 
 
 def make_inventory(hosts=("somehost", "anotherhost"), **kwargs):
@@ -66,7 +65,7 @@ def parse_value(value):
 
     if isinstance(value, str):
         if value.startswith("datetime:"):
-            return datetime.strptime(value[9:], "%Y-%m-%dT%H:%M:%S")
+            return datetime.fromisoformat(value[9:])
         if value.startswith("path:"):
             return Path(value[5:])
         return value
@@ -162,8 +161,9 @@ class FakeHost:
 
     # Current context inside an @operation function
     in_op = True
+    in_callback_op = False
     current_op_hash = None
-    current_op_global_kwargs = None
+    current_op_global_arguments = None
 
     # Current context inside a @deploy function
     in_deploy = True
@@ -171,7 +171,8 @@ class FakeHost:
     current_deploy_kwargs = None
     current_deploy_data = None
 
-    def __init__(self, name, facts, data):
+    def __init__(self, state, name, facts, data):
+        self.state = state
         self.name = name
         self.fact = FakeFacts(facts)
         self.data = data
@@ -184,6 +185,19 @@ class FakeHost:
     def noop(self, description):
         self.noop_description = description
 
+    def get_temp_filename(*args, **kwargs):
+        return "_tempfile_"
+
+    def get_file(
+        self,
+        remote_filename,
+        filename_or_io,
+        remote_temp_filename=None,
+        print_output=False,
+        *arguments,
+    ):
+        return True
+
     @staticmethod
     def _get_fact_key(fact_cls):
         return "{0}.{1}".format(fact_cls.__module__.split(".")[-1], fact_cls.__name__)
@@ -192,51 +206,32 @@ class FakeHost:
     def _check_fact_args(fact_cls, kwargs):
         # Check that the arguments we're going to use to fake a fact are all actual arguments in
         # the fact class, otherwise the test will hide a bug in the underlying operation.
-        real_args = getfullargspec(fact_cls.command)
-        for key in kwargs.keys():
-            assert (
-                key in real_args.args
-            ), f"Argument {key} is not a real argument in the `{fact_cls}.command` method"
+        real_args = getfullargspec(fact_cls.command).args
 
-    def get_fact(self, fact_cls, **kwargs):
+        for key in kwargs.keys():
+            assert key in real_args, (
+                f"Argument {key} is not a real argument in the `{fact_cls}.command` method"
+            )
+
+    def get_fact(self, fact_cls, *args, **kwargs):
         fact_key = self._get_fact_key(fact_cls)
         fact = getattr(self.fact, fact_key, None)
         if fact is None:
-            raise KeyError("Missing test fact data: {0}".format(fact_key))
+            raise KeyError(f"Missing test fact: {fact_key}")
+
+        # This does the same thing that pyinfra.apit.facts._handle_fact_kwargs does
+        if args or kwargs:
+            # Merges args & kwargs into a single kwargs dictionary
+            kwargs = getcallargs(fact_cls().command, *args, **kwargs)
+
         if kwargs:
             self._check_fact_args(fact_cls, kwargs)
-            fact_ordered_keys = {_sort_kwargs_str(key): value for key, value in fact.items()}
-            kwargs_str = _sort_kwargs_str(get_kwargs_str(kwargs))
+            kwargs_str = get_kwargs_str(kwargs)
             if kwargs_str not in fact:
-                logger.info("Possible missing fact key: {0}".format(kwargs_str))
-            return fact_ordered_keys.get(kwargs_str)
+                raise KeyError(f"Missing test fact key: {fact_key} -> {kwargs_str}")
+            return fact.get(kwargs_str)
         return fact
 
-    def create_fact(self, fact_cls, data=None, kwargs=None):
-        try:
-            fact = self.get_fact(fact_cls)
-        except KeyError:
-            fact_key = self._get_fact_key(fact_cls)
-            fact = self.fact[fact_key] = {}
-        if kwargs:
-            fact[_sort_kwargs_str(get_kwargs_str(kwargs))] = data
-        else:
-            fact_key = self._get_fact_key(fact_cls)
-            self.fact[fact_key] = data
-
-    def delete_fact(self, fact_cls, kwargs=None):
-        try:
-            fact = self.get_fact(fact_cls)
-        except KeyError:
-            return
-
-        ordered_kwargs = _sort_kwargs_str(get_kwargs_str(kwargs))
-        for key in fact.keys():
-            ordered_key = _sort_kwargs_str(key)
-            if ordered_key == ordered_kwargs:
-                fact.pop(key)
-                break
-
 
 class FakeFile:
     _read = False
@@ -264,7 +259,7 @@ class FakeFile:
                 return self._data.split()
             return ["_test_data_"]
 
-            return []
+        return []
 
     def seek(self, *args, **kwargs):
         pass
@@ -324,6 +319,7 @@ class patch_files:
             patch("pyinfra.operations.files.os.path.isfile", self.isfile),
             patch("pyinfra.operations.files.os.path.isdir", self.isdir),
             patch("pyinfra.operations.files.os.walk", self.walk),
+            patch("pyinfra.operations.files.os.stat", self.stat),
             patch("pyinfra.operations.files.os.makedirs", lambda path: True),
             patch("pyinfra.api.util.stat", self.stat),
             # Builtin patches
@@ -358,14 +354,98 @@ class patch_files:
         return normalized_path in self._directories
 
     def stat(self, pathname):
+        try:
+            fileinfo = copy.deepcopy(self._files_data[pathname])
+            if not fileinfo:
+                fileinfo = dict()
+        except KeyError:
+            fileinfo = dict()
+
         if self.isfile(pathname):
-            mode_int = 33188  # 644 file
+            default_mode = 33188  # 644 file
         elif self.isdir(pathname):
-            mode_int = 16877  # 755 directory
+            default_mode = 16877  # 755 directory
         else:
             raise IOError("No such file or directory: {0}".format(pathname))
 
-        return os.stat_result((mode_int, 0, 0, 0, 0, 0, 0, 0, 0, 0))
+        default_timeval = datetime.fromisoformat("2008-08-09T13:21:44").timestamp()
+        defaults = dict(
+            mode=default_mode, ino=64321, dev=64556, nlink=1, uid=1001, gid=1001, size=10240
+        )
+
+        if "mode" in fileinfo.keys():
+            if isinstance(fileinfo["mode"], str):
+                perms = int(fileinfo["mode"], 8)
+            else:
+                # this assumes the mode was provided as an integer whose digits are really octal
+                perms = int(str(fileinfo["mode"]), 8)
+
+            if self.isfile(pathname):
+                fileinfo["mode"] = 0o100000 + perms
+            else:
+                fileinfo["mode"] = 0o40000 + perms
+        else:
+            fileinfo["mode"] = defaults["mode"]
+
+        for field in ["dev", "nlink", "uid", "gid", "size"]:
+            if field in fileinfo.keys():
+                if isinstance(fileinfo[field], str):
+                    fileinfo[field] = int(fileinfo[field])
+            else:
+                fileinfo[field] = defaults[field]
+
+        # support both "ino" and "inode" as keys for st_ino
+        if "ino" in fileinfo.keys():
+            if isinstance(fileinfo["ino"], str):
+                fileinfo["ino"] = int(fileinfo["ino"])
+        elif "inode" in fileinfo.keys():
+            if isinstance(fileinfo["inode"], str):
+                fileinfo["ino"] = int(fileinfo["inode"])
+            else:
+                fileinfo["ino"] = fileinfo["inode"]
+        else:
+            fileinfo["ino"] = defaults["ino"]
+
+        for timefield in ["atime", "mtime", "ctime"]:
+            if timefield in fileinfo.keys():
+                if not isinstance(fileinfo[timefield], (int, float, str)):
+                    raise TypeError("Parameter {0} must have type float, int or str", timefield)
+
+                if isinstance(fileinfo[timefield], str):
+                    if fileinfo[timefield].startswith("datetime:"):
+                        timestr = fileinfo[timefield].removeprefix("datetime:")
+                        dt = datetime.fromisoformat(timestr.strip())
+                        if not dt.tzinfo:
+                            dt = dt.replace(tzinfo=timezone.utc)
+                        fileinfo[timefield] = dt.timestamp()
+                    elif re.match("^-?[0-9]+$", fileinfo[timefield].strip()):
+                        fileinfo[timefield] = int(fileinfo[timefield].strip())
+                    elif re.match("^-?[0-9]+(\\.[0-9]*)?$", fileinfo[timefield].strip()):
+                        fileinfo[timefield] = float(fileinfo[timefield].strip())
+                    else:
+                        raise ValueError(
+                            "Invalid argument: {0} for {1}", fileinfo[timefield], timefield
+                        )
+            else:
+                fileinfo[timefield] = default_timeval
+
+        return os.stat_result(
+            tuple(
+                fileinfo[field]
+                for field in [
+                    "mode",
+                    "ino",
+                    "dev",
+                    "nlink",
+                    "uid",
+                    "gid",
+                    "size",
+                    "atime",
+                    "mtime",
+                    "ctime",
+                ]
+            )
+        )
 
     def walk(self, dirname, topdown=True, onerror=None, followlinks=False):
         if not self.isdir(dirname):
@@ -384,7 +464,7 @@ class patch_files:
                 yield recursive_return
 
 
-def create_host(name=None, facts=None, data=None):
+def create_host(state, name=None, facts=None, data=None):
     """
     Creates a FakeHost object with attached fact data.
     """
@@ -396,35 +476,4 @@ def create_host(name=None, facts=None, data=None):
     for name, fact_data in facts.items():
         real_facts[name] = fact_data
 
-    return FakeHost(name, facts=real_facts, data=data)
-
-
-class JsonTest(type):
-    def __new__(cls, name, bases, attrs):
-        # Get the JSON files
-        files = listdir(attrs["jsontest_files"])
-        files = [f for f in files if f.endswith(".json")]
-
-        test_prefix = attrs.get("jsontest_prefix", "test_")
-
-        def gen_test(test_name, filename):
-            def test(self):
-                test_data = json.loads(
-                    open(
-                        path.join(attrs["jsontest_files"], filename),
-                        encoding="utf-8",
-                    ).read(),
-                )
-                self.jsontest_function(test_name, test_data)
-
-            return test
-
-        # Loop them and create class methods to call the jsontest_function
-        for filename in files:
-            test_name = filename[:-5]
-
-            # Attach the method
-            method_name = "{0}{1}".format(test_prefix, test_name)
-            attrs[method_name] = gen_test(test_name, filename)
-
-        return type.__new__(cls, name, bases, attrs)
+    return FakeHost(state, name, facts=real_facts, data=data)
